@@ -183,7 +183,7 @@ let rec skip s k = match s with
     let len = String.length s in
     let len64 = Int64.of_int len in
     if Int64.compare k len64 <= 0
-    then 
+    then
       let k = Int64.to_int k in
       Lwt.return (Cont (String.sub s k (len - k), f))
     else (enlarge_stream (Cont ("", f)) >>=
@@ -211,7 +211,7 @@ let substream delim s =
           with Not_found ->
             let pos = (len + 1 - ldelim) in
             cont (String.sub s 0 pos)
-              (fun () -> 
+              (fun () ->
                  next f >>= function
                  | Finished _ -> Lwt.fail Stream_too_small
                  | Cont (s', f') ->
@@ -229,14 +229,14 @@ let of_file filename =
   let fd = Lwt_unix.of_unix_file_descr
       (Unix.openfile filename [Unix.O_RDONLY;Unix.O_NONBLOCK] 0o666)
   in
-  let ch = Lwt_chan.in_channel_of_descr fd in
+  let ch = Lwt_io.of_fd ~mode:Lwt_io.input fd in
   let buf = Bytes.create 1024 in
   let rec aux () =
-    Lwt_chan.input ch buf 0 1024 >>= fun n ->
+    Lwt_io.read_into ch buf 0 1024 >>= fun n ->
     if n = 0 then empty None else
       (* Streams should be immutable, thus we always make a copy
          of the buffer *)
-      cont (Bytes.sub buf 0 n) aux
+      cont (Bytes.sub_string buf 0 n) aux
   in make ~finalize:(fun _ -> Lwt_unix.close fd) aux
 
 let of_string s =
