@@ -34,8 +34,7 @@ module Make_XML_Content(Xml : Xml_sigs.Iterable)
     (Typed_xml : Xml_sigs.Typed_xml with module Xml := Xml)
 = struct
 
-  module Htmlprinter =
-    Xml_print.Make_typed(Xml)(Typed_xml)(Ocsigen_stream.StringStream)
+  module Htmlprinter = Xml_print.Make_typed_fmt(Xml)(Typed_xml)
 
   type t = Typed_xml.doc
   type options = Http_headers.accept Lazy.t
@@ -65,7 +64,9 @@ module Make_XML_Content(Xml : Xml_sigs.Iterable)
         Typed_xml.Info.alternative_content_types
         Typed_xml.Info.content_type in
     let encode x = fst (Xml_print.Utf8.normalize_html x) in
-    let x = Htmlprinter.print ~encode ~advert c in
+    let x =
+      Ocsigen_stream.of_string
+        (Format.asprintf "%a" (Htmlprinter.pp ~encode ~advert ()) c) in
     let default_result = Result.default () in
     Lwt.return
       (Result.update default_result
@@ -77,7 +78,7 @@ module Make_XML_Content(Xml : Xml_sigs.Iterable)
          ~stream:(x, None) ())
 end
 
-module Html5_content = Make_XML_Content(Xml)(Html5.M)
+module Html_content = Make_XML_Content(Tyxml.Xml)(Tyxml.Html)
 
 
 (*****************************************************************************)
@@ -97,7 +98,7 @@ struct
      etag match and respond with code 412 ( precondition failed ).
      Since the etag is calculated from the content of the answer,
      we cannot enforce this semantic correctly, so it is better not
-     to send etags with POST requests. Here, we cannot know wether
+     to send etags with POST requests. Here, we cannot know whether
      the request was in POST or GET, so the easiest way to fix that
      is to never send etags *)
 
@@ -213,7 +214,7 @@ end
 (*****************************************************************************)
 (* Files *)
 
-(** this module instanciate the HTTP_CONTENT signature for files *)
+(** this module instantiate the HTTP_CONTENT signature for files *)
 module File_content =
 struct
   type t =
@@ -236,8 +237,9 @@ struct
         Ocsigen_stream.empty None
       else begin
         if read = buffer_size
-        then Ocsigen_stream.cont buf read_aux
-        else Ocsigen_stream.cont (String.sub buf 0 read) read_aux
+        then Ocsigen_stream.cont (Bytes.to_string buf) read_aux
+        (* copying :( *)
+        else Ocsigen_stream.cont (Bytes.sub_string buf 0 read) read_aux
       end
     in read_aux
 
@@ -298,7 +300,7 @@ end
 (*****************************************************************************)
 (* directory listing - by Gabriel Kerneis *)
 
-(** this module instanciate the HTTP_CONTENT signature for directories *)
+(** this module instantiate the HTTP_CONTENT signature for directories *)
 module Directory_content =
 struct
   type t = string (* dir name *) * string list (* corresponding URL path *)
@@ -473,11 +475,11 @@ struct
   let get_etag ?options c = None
 
   let error_page s msg c =
-    Html5.M.html
-      (Html5.M.head (Html5.M.title (Html5.M.pcdata s)) [])
-      (Html5.M.body
-         (Html5.M.h1 [Html5.M.pcdata msg]::
-          Html5.M.p [Html5.M.pcdata s]::
+    Tyxml.Html.html
+      (Tyxml.Html.head (Tyxml.Html.title (Tyxml.Html.pcdata s)) [])
+      (Tyxml.Html.body
+         (Tyxml.Html.h1 [Tyxml.Html.pcdata msg]::
+          Tyxml.Html.p [Tyxml.Html.pcdata s]::
           c)
       )
 
@@ -512,11 +514,11 @@ struct
         error_page
           ("Error "^str_code)
           error_msg
-          [Html5.M.p
-             [Html5.M.pcdata (Printexc.to_string exn);
-              Html5.M.br ();
-              Html5.M.em
-                [Html5.M.pcdata "(Ocsigen running in debug mode)"]
+          [Tyxml.Html.p
+             [Tyxml.Html.pcdata (Printexc.to_string exn);
+              Tyxml.Html.br ();
+              Tyxml.Html.em
+                [Tyxml.Html.pcdata "(Ocsigen running in debug mode)"]
              ]]
       | _ ->
         error_page
@@ -524,7 +526,7 @@ struct
           error_msg
           []
     in
-    Html5_content.result_of_content err_page >>= fun r ->
+    Html_content.result_of_content err_page >>= fun r ->
     Lwt.return
       (Result.update r
          ~cookies:cookies_to_set
