@@ -108,7 +108,7 @@ let connection_table = T.create 100
   in order to try to pipeline them on the same output connection.
 
   If the client parameter is not present, we do the
-  requests independantly.
+  requests independently.
   We try to find a free connection to the right server
   or we create one if there is none.
   In that case, the distant server may have the request in wrong order.
@@ -231,13 +231,13 @@ let appreciate_server_pipeline inet_addr port =
         | Yes -> None
         | No t when Unix.time () -. t < purgatory_delay -> None
         | No t ->
-          Lwt_log.ign_warning_f ~section
+          Lwt_log.ign_notice_f ~section
             "Give to server %a:%d a new probing period for pipelining."
             (fun () -> Unix.string_of_inet_addr) inet_addr port;
           Some purgatory_time (* second chance *)
         | Probing n -> Some (n-1)
     with Not_found ->
-      Lwt_log.ign_warning_f ~section
+      Lwt_log.ign_notice_f ~section
         "Give to server %a:%d a first probing period for pipelining." (fun () -> Unix.string_of_inet_addr) inet_addr port;
       Some probing_time
   with
@@ -292,13 +292,16 @@ let handle_connection_error fd exn = match exn with
     >>= fun () ->  Lwt.fail
       (Ocsigen_http_frame.Http_error.Http_exception
          (504, Some "Distant server closed connection", None))
-  | e -> Lwt_unix.close fd >>= fun () ->  Lwt.fail e
+  | e ->
+    Lwt.catch (fun () -> Lwt_unix.close fd) (fun _ -> Lwt.return ())
+    >>= fun () ->  Lwt.fail e
 
 
 let raw_request
     ?client ?(keep_alive = true) ?headers ?(https=false) ?port
     ~content ?content_length ~http_method ~host ~inet_addr ~uri () =
 
+  let uri = if uri = "" then "/" else uri in
 
   let head = http_method = Ocsigen_http_frame.Http_header.HEAD in
 
@@ -559,7 +562,13 @@ let raw_request
           Lwt_log.ign_info ~section ~exn
             "exception while trying to keep free connection";
           !ref_thr_conn >>= fun conn ->
-          Lwt_ssl.close (Ocsigen_http_com.connection_fd conn)
+          (* We can arrive here when there the server has closed the
+             connection. In this case, we have already closed the
+             connection as well, and we should ignore the error
+             when attempting to close it again below. *)
+          Lwt.catch
+            (fun () -> Lwt_ssl.close (Ocsigen_http_com.connection_fd conn))
+            (fun _ -> Lwt.return ())
       in
       if do_keep_alive then begin
         match key_new_waiter with
