@@ -36,13 +36,13 @@ val parse_size_tag : string -> string -> int64 option
 (** Parse a string (PCDATA) as XML content.
     Raises [Failure "Ocsigen_parseconfig.parse_string"] in case of error.
 *)
-val parse_string : Simplexmlparser.xml list -> string
+val parse_string : Xml.xml list -> string
 
 (** [parse_string_tag tag s] parses a string (same syntax as [parse_string]).
     In case of error, raises [Ocsigen_config.Config_file_error m] where [m]
     is an error message explaining that a string was expected in tag [<tag>].
 *)
-val parse_string_tag : string -> Simplexmlparser.xml list -> string
+val parse_string_tag : string -> Xml.xml list -> string
 
 
 (** Parses the [hostfilter] field of the configuration file, which
@@ -52,24 +52,32 @@ val parse_host_field: string option -> Ocsigen_extensions.virtual_hosts
 
 (**/**)
 
-val parser_config : Simplexmlparser.xml list ->
-  Simplexmlparser.xml list list
-val parse_server : bool -> Simplexmlparser.xml list -> unit
+val parser_config : Xml.xml -> Xml.xml list list
+val parse_server : bool -> Xml.xml list -> unit
 
-(** First pass of parse XML file. Extracts this informations:
+type ssl_info = {
+  ssl_certificate : string option;
+  ssl_privatekey  : string option;
+  ssl_ciphers     : string option;
+  ssl_dhfile      : string option;
+  ssl_curve       : string option
+}
+
+(** First pass of parse XML file. Extracts this information:
     {ul
     {- user to execute OcsigenServer (ex: www-data) }
     {- group to execute OcsigenServer (ex: www-data) }
-    {- SSL key and SSL certificate }
+    {- SSL key, SSL certificate, SSL ciphers list,
+       SSL DH file, SSL EC curve }
     {- list of HTTP port to listen (ex: 80) }
     {- list of HTTPS port to listen (ex: 443) }
     {- minimum and maximum of threads }
     }
 *)
 val extract_info :
-  Simplexmlparser.xml list ->
+  Xml.xml list ->
   (string option * string option) *
-  ((string option * string option) option *
+  (ssl_info option *
    (Ocsigen_socket.socket_type * int) list *
    (Ocsigen_socket.socket_type * int) list) *
   (int * int)
@@ -77,4 +85,4 @@ val extract_info :
 val parse_config :
   ?file:string ->
   unit ->
-  Simplexmlparser.xml list list
+  Xml.xml list list
